https://github.com/python/cpython/commit/e4238e6b785d59ba711bf00d77319abe900ec519
commit: e4238e6b785d59ba711bf00d77319abe900ec519
branch: 3.13
author: Miss Islington (bot) <[email protected]>
committer: chris-eibl <[email protected]>
date: 2026-09-03T19:56:30+02:00
summary:

[3.13] gh-94242: Clarify comments for _MAX_WINDOWS_WORKERS in 
concurrent.futures.process (GH-135537) (#156907)

gh-94242: Clarify comments for _MAX_WINDOWS_WORKERS in 
concurrent.futures.process (GH-135537)
(cherry picked from commit c8ea8676d931a3b42a428123070628f9ba8390db)

Co-authored-by: An Long <[email protected]>

files:
M Lib/concurrent/futures/process.py

diff --git a/Lib/concurrent/futures/process.py 
b/Lib/concurrent/futures/process.py
index 6a1b69aea807531..8d0a130b6e04acf 100644
--- a/Lib/concurrent/futures/process.py
+++ b/Lib/concurrent/futures/process.py
@@ -119,10 +119,11 @@ def _python_exit():
 
 
 # On Windows, WaitForMultipleObjects is used to wait for processes to finish.
 # It can wait on, at most, 63 objects. There is an overhead of two objects:
 # - the result queue reader
 # - the thread wakeup reader
-_MAX_WINDOWS_WORKERS = 63 - 2
+# - the SIGINT handler
+_MAX_WINDOWS_WORKERS = 64 - 3
 
 # Hack to embed stringification of remote traceback in local traceback
 
@@ -119,10 +119,11 @@ def _python_exit():
 
 # On Windows, WaitForMultipleObjects is used to wait for processes to finish.
-# It can wait on, at most, 63 objects. There is an overhead of two objects:
+# It can wait on, at most, 64 objects. There is an overhead of three objects:
 # - the result queue reader
 # - the thread wakeup reader

_______________________________________________
Python-checkins mailing list -- [email protected]
To unsubscribe send an email to [email protected]
https://mail.python.org/mailman3//lists/python-checkins.python.org
Member address: [email protected]

Reply via email to